@@ -24,13 +24,15 @@ from datetime import date
 
 COPYRIGHT_SIGNATURE = re.compile(r"\bcopyright\b", re.I)
 CHECKED_FILES = re.compile(
-    r".*(\.(i?[ch](pp|xx|c)?|cc|hh|py|C|cmake|[yx]ml|qm[ts]|dtd|xsd|ent|bat|[cz]?sh|js|html?)|"
+    r".*(\.(i?[ch](pp|xx|c)?|cc|hh|py|cuh?|C|cmake|[yx]ml|qm[ts]|dtd|xsd|ent|bat|[cz]?sh|js|html?)|"
     r"CMakeLists.txt|Jenkinsfile)$"
 )
 
 COPYRIGHT_STATEMENT = """
 (c) Copyright {} CERN for the benefit of the LHCb Collaboration
+"""
 
+GPL3_STATEMENT = """
 This software is distributed under the terms of the GNU General Public
 Licence version 3 (GPL Version 3), copied verbatim in the file "{}".
 
@@ -39,6 +41,17 @@ granted to it by virtue of its status as an Intergovernmental Organization
 or submit itself to any jurisdiction.
 """
 
+APACHE2_STATEMENT = """
+This software is distributed under the terms of the Apache License
+version 2 (Apache-2.0), copied verbatim in the file "{}".
+
+In applying this licence, CERN does not waive the privileges and immunities
+granted to it by virtue of its status as an Intergovernmental Organization
+or submit itself to any jurisdiction.
+"""
+
+licenses = {"GPL-3.0-only": GPL3_STATEMENT, "Apache-2.0": APACHE2_STATEMENT}
+
 # see https://www.python.org/dev/peps/pep-0263 for the regex
 ENCODING_DECLARATION = re.compile(
     r"^[ \t\f]*#.*?coding[:=][ \t]*([-_.a-zA-Z0-9]+)".encode()
@@ -123,7 +136,7 @@ def get_files(reference=None):
     return (path for path in all if to_check(path))
 
 
-def report(filenames, inverted=False, target=None):
+def report(filenames, inverted=False, target=None, license="GPL-3.0-only"):
     """
     Print a report with the list of filenames.
 
@@ -137,14 +150,21 @@ def report(filenames, inverted=False, target=None):
     )
     print("\n- ".join(filenames))
     if not inverted:
+        license_arg = (
+            " --license={}".format(license) if license != "GPL-3.0-only" else ""
+        )
         if target:
             print(
-                "\nYou can fix the {} files without copyright statement "
-                "with:\n\n  $ lb-check-copyright --porcelain {} "
-                "| xargs -r lb-add-copyright\n".format(len(filenames), target)
+                "\nYou can fix the {0} files without copyright statement "
+                "with:\n\n  $ lb-check-copyright --porcelain {1}{2} "
+                "| xargs -r lb-add-copyright{2}\n".format(
+                    len(filenames), target, license_arg
+                )
             )
         else:
-            print("\nyou can fix them with the command lb-add-copyright\n")
+            print("\nyou can fix them with the command lb-add-copyright{}\n").format(
+                license_arg
+            )
 
 
 def to_comment(text, lang_family="#", width=80):
@@ -204,7 +224,9 @@ def lang_family(path):
     """
     if re.match(r".*\.(xml|xsd|dtd|html?|qm[ts]|ent)$", path):
         return "xml"
-    elif re.match(r"(.*\.(i?[ch](pp|xx|c)?|cc|hh|C|opts|js)|" r"Jenkinsfile)$", path):
+    elif re.match(
+        r"(.*\.(i?[ch](pp|xx|c)?|cuh?|cc|hh|C|opts|js)|" r"Jenkinsfile)$", path
+    ):
         return "c"
     elif re.match(r".*\.py$", path) or re.match(
         r"^#!.*python", open(path).readline(120)
@@ -224,19 +246,17 @@ def find_encoding_declaration_line(lines, limit=2):
             return i
 
 
-def add_copyright_to_file(path, year=None, license_fn=None):
+def add_copyright_to_file(path, year=None, license_fn=None, add_license="GPL-3.0-only"):
     """
     Add copyright statement to the given file for the specified year (or range
     of years).  If the year argument is not specified, the current year is
     used.
     """
     lang = lang_family(path)
-    text = to_comment(
-        COPYRIGHT_STATEMENT.format(
-            year or date.today().year, license_fn or "COPYING"
-        ).strip(),
-        lang,
-    )
+    statement = COPYRIGHT_STATEMENT.format(year or date.today().year)
+    statement += licenses[add_license].format(license_fn or "COPYING")
+
+    text = to_comment(statement.strip(), lang)
     with open(path, "rb") as f:
         data = f.readlines()
 
@@ -244,7 +264,7 @@ def add_copyright_to_file(path, year=None, license_fn=None):
     encoding_offset = find_encoding_declaration_line(data)
     if encoding_offset is not None:
         offset = encoding_offset + 1
-    elif data[0].startswith(b"#!"):
+    elif data and data[0].startswith(b"#!"):
         offset = 1
     elif lang == "xml":
         offset = 1 if not path.endswith(".ent") else 0
@@ -460,6 +480,12 @@ def check_copyright():
         const="\x00",
         help="when using --porcelain, paths are separated with NUL character",
     )
+    parser.add_argument(
+        "--license",
+        default="GPL-3.0-only",
+        choices=["GPL-3.0-only", "Apache-2.0"],
+        help="Add a license statement of the specified type",
+    )
     parser.add_argument(
         "--inverted",
         action="store_true",
@@ -491,7 +517,7 @@ def check_copyright():
     if missing:
         missing.sort()
         if not args.porcelain:
-            report(missing, args.inverted, args.reference)
+            report(missing, args.inverted, args.reference, args.license)
         else:
             print(args.separator.join(missing), end=args.separator)
         exit(1)
@@ -510,6 +536,12 @@ def add_copyright():
     parser.add_argument(
         "--license-fn", help="Name of the license file (default: COPYING)"
     )
+    parser.add_argument(
+        "--license",
+        default="GPL-3.0-only",
+        choices=["GPL-3.0-only", "Apache-2.0"],
+        help="Add a license statement of the specified type",
+    )
     parser.add_argument(
         "--force",
         action="store_true",
@@ -527,7 +559,7 @@ def add_copyright():
         elif has_copyright(path):
             print("warning: {} already has a copyright statement".format(path))
         else:
-            add_copyright_to_file(path, args.year, args.license_fn)
+            add_copyright_to_file(path, args.year, args.license_fn, args.license)
 
 
 def format():
